
#ifndef _C12_re582_
#define _C12_re582_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1256_13780(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit582(void);
extern char *(*R2999[])();

#ifdef __cplusplus
}
#endif

#endif
